==> grai_schemas-0.1.14.tar.gz: grai_schemas-0.1.14/src/grai_schemas/v1/metadata/edges.py <==
from enum import Enum
from typing import Any, Dict, List, Literal, Optional, Union

from grai_schemas.generics import MalformedMetadata
from grai_schemas.v1.generics import V1Mixin
from grai_schemas.v1.metadata.generics import GenericAttributes


class EdgeTypeLabels(Enum):
    """ """

    generic = "Generic"
    table_to_column = "TableToColumn"
    column_to_column = "ColumnToColumn"
    table_to_table = "TableToTable"


EdgeTypeLabelLiterals = Literal["Generic", "TableToColumn", "ColumnToColumn", "TableToTable"]


class BaseEdgeMetadataV1(V1Mixin):
    """ """

    type: Literal["EdgeV1"] = "EdgeV1"
    edge_type: EdgeTypeLabelLiterals
    edge_attributes: GenericAttributes
    tags: Optional[List[str]]


class MalformedEdgeMetadataV1(MalformedMetadata, BaseEdgeMetadataV1):
    edge_type: Optional[str] = "Malformed"
    edge_attributes: Optional[Any] = GenericAttributes()


class GenericEdgeMetadataV1(BaseEdgeMetadataV1):
    edge_type: Literal["Generic"]
    edge_attributes: GenericAttributes = GenericAttributes()


class TableToColumnAttributes(GenericAttributes):
    """ """

    pass


class TableToColumnMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["TableToColumn"]
    edge_attributes: TableToColumnAttributes = TableToColumnAttributes()


class TableToTableAttributes(GenericAttributes):
    """ """

    pass


class TableToTableMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["TableToTable"]
    edge_attributes: TableToTableAttributes = TableToTableAttributes()


class ColumnToColumnAttributes(GenericAttributes):
    """ """

    preserves_data_type: Optional[bool] = None
    preserves_nullable: Optional[bool] = None
    preserves_unique: Optional[bool] = None


class ColumnToColumnMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["ColumnToColumn"]
    edge_attributes: ColumnToColumnAttributes = ColumnToColumnAttributes()


Metadata = Union[TableToColumnMetadata, TableToTableMetadata, ColumnToColumnMetadata, GenericEdgeMetadataV1]

==> grai_schemas-0.2.0a2.tar.gz: grai_schemas-0.2.0a2/src/grai_schemas/v1/metadata/edges.py <==
from enum import Enum
from typing import Any, Dict, List, Literal, Optional, Union

from grai_schemas.generics import MalformedMetadata
from grai_schemas.v1.generics import V1Mixin
from grai_schemas.v1.metadata.generics import GenericAttributes


class EdgeMetadataTypeLabels(Enum):
    """ """

    generic = "Generic"
    table_to_column = "TableToColumn"
    column_to_column = "ColumnToColumn"
    table_to_table = "TableToTable"


EdgeTypeLabelLiterals = Literal["Generic", "TableToColumn", "ColumnToColumn", "TableToTable"]


class BaseEdgeMetadataV1(V1Mixin):
    """ """

    type: Literal["EdgeV1"] = "EdgeV1"
    edge_type: EdgeTypeLabelLiterals
    edge_attributes: GenericAttributes
    tags: Optional[List[str]]


class MalformedEdgeMetadataV1(MalformedMetadata, BaseEdgeMetadataV1):
    edge_type: Optional[str] = "Malformed"  # type: ignore
    edge_attributes: Optional[Any] = GenericAttributes()  # type: ignore


class GenericEdgeMetadataV1(BaseEdgeMetadataV1):
    edge_type: Literal["Generic"]
    edge_attributes: GenericAttributes = GenericAttributes()


class TableToColumnAttributes(GenericAttributes):
    """ """

    pass


class TableToColumnMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["TableToColumn"]
    edge_attributes: TableToColumnAttributes = TableToColumnAttributes()


class TableToTableAttributes(GenericAttributes):
    """ """

    pass


class TableToTableMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["TableToTable"]
    edge_attributes: TableToTableAttributes = TableToTableAttributes()


class ColumnToColumnAttributes(GenericAttributes):
    """ """

    preserves_data_type: Optional[bool] = None
    preserves_nullable: Optional[bool] = None
    preserves_unique: Optional[bool] = None


class ColumnToColumnMetadata(BaseEdgeMetadataV1):
    """ """

    edge_type: Literal["ColumnToColumn"]
    edge_attributes: ColumnToColumnAttributes = ColumnToColumnAttributes()


Metadata = Union[TableToColumnMetadata, TableToTableMetadata, ColumnToColumnMetadata, GenericEdgeMetadataV1]
